"use strict";
var assert = require("assert");
var path = require("path");
var compiler_1 = require("./../../../compiler");
var utils_1 = require("./../../../utils");
describe("CompilerOptionsResolver", function () {
    describe("getCompilerOptions", function () {
        describe("nothing", function () {
            it("should get the default compiler options when not providing anything", function () {
                var resolver = new compiler_1.CompilerOptionsResolver();
                var compilerOptions = resolver.getCompilerOptions({});
                assert.deepEqual(compilerOptions, getDefaultCompilerOptions());
            });
        });
        describe("compilerOptions", function () {
            it("should get the default compiler options when providing an empty compiler options object", function () {
                var resolver = new compiler_1.CompilerOptionsResolver();
                var compilerOptions = resolver.getCompilerOptions({
                    compilerOptions: {}
                });
                assert.deepEqual(compilerOptions, getDefaultCompilerOptions());
            });
            it("should use compiler options when providing a tsconfig path", function () {
                var resolver = new compiler_1.CompilerOptionsResolver();
                var compilerOptions = resolver.getCompilerOptions({
                    tsConfigFilePath: "test.txt",
                    compilerOptions: {
                        rootDir: "test",
                        target: 1
                    }
                });
                assert.deepEqual(compilerOptions, utils_1.objectAssign(getDefaultCompilerOptions(), { rootDir: "test", target: 1 }));
            });
        });
        describe("tsConfigFilePath", function () {
            it("should use compiler options from the tsconfig when providing a tsconfig path", function () {
                var resolver = new compiler_1.CompilerOptionsResolver();
                var compilerOptions = resolver.getCompilerOptions({
                    tsConfigFilePath: path.join(__dirname, "./../../../../src/tests/compiler/utils/tsconfigTestFile.txt")
                });
                assert.deepEqual(compilerOptions, utils_1.objectAssign(getDefaultCompilerOptions(), {
                    module: 1,
                    noImplicitAny: true,
                    removeComments: true,
                    preserveConstEnums: true,
                    sourceMap: true
                }));
            });
        });
    });
});
function getDefaultCompilerOptions() {
    return {
        allowJs: true,
        experimentalDecorators: true,
        moduleResolution: 2,
        noImplicitAny: false,
        noLib: false,
        strictNullChecks: false,
        suppressExcessPropertyErrors: true,
        suppressImplicitAnyIndexErrors: true,
        target: 2
    };
}

//# sourceMappingURL=compilerOptionsResolverTests.js.map
